/// <reference types="node" />
export declare type FetchOpts = Omit<RequestInit, 'body'> & {
    opening?: boolean;
    token?: string;
    endpoint?: string;
    requestType?: 'buffer' | 'stream' | 'json';
    responseType?: 'json' | 'text' | 'buffer' | 'stream' | 'raw';
    params?: Record<string, any>;
    headers?: Record<string, string>;
    log?: (msg: string) => void;
    body?: BodyInit | Uint8Array | Buffer | ReadableStream | any;
};
/**
 * Fetch a resource.
 *
 * This is a wrapper around the fetch web API. It should be API compatible to fetch,
 * with the following changes:
 *
 * TODO: Rethink the default responseType cascade.
 *
 * @async
 * @param {string} url - The url to fetch
 * @param {string} [opts.endpoint=''] Endpoint URL (will be prefixed to URL)
 * @param {string} [opts.requestType='json'] Request encoding and content type.
 *   Supported values are 'json' and 'binary'
 * @param {string} [opts.responseType='text'] Response encoding. If the response
 *    has a JSON content type, will always be set to 'json'.
 *    Supported values are 'text', 'binary' and 'stream'.
 * @param {object} [opts.params] Query string parameters (will be encoded correctly).
 *
 * @return {Promise<object>} If the response has a JSON content type header, the
 *    decoded JSON will be returned. if opts.responseType is 'binary' or 'text',
 *    the response will be returned as a buffer or text.
 */
export default function makeFetch(url: string, opts: FetchOpts & {
    responseType: 'text';
}): Promise<string>;
export default function makeFetch(url: string, opts: FetchOpts & {
    responseType: 'buffer';
}): Promise<Buffer | ArrayBuffer>;
export default function makeFetch(url: string, opts: FetchOpts & {
    responseType: 'stream';
}): Promise<ReadableStream<Uint8Array>>;
export default function makeFetch(url: string, opts: FetchOpts & {
    responseType: 'raw';
}): Promise<Response>;
export default function makeFetch(url: string, opts: FetchOpts): Promise<any>;
//# sourceMappingURL=fetch.d.ts.map